@@ -1,11 +1,12 @@
 package Koha::Contrib::Tamil::RecordWriter::File::Marcxml;
 {
-  $Koha::Contrib::Tamil::RecordWriter::File::Marcxml::VERSION = '0.013';
+  $Koha::Contrib::Tamil::RecordWriter::File::Marcxml::VERSION = '0.014';
 }
 # ABSTRACT: XML MARC record reader
 use Moose;
 
-extends 'Koha::Contrib::Tamil::RecordWriter::File';
+with 'MooseX::RW::Writer::File';
+
 
 use Carp;
 use MARC::Batch;
@@ -45,9 +46,9 @@ sub DEMOLISH {
 # Sent record is rather a MARC::Record object or an marcxml string
 #
 sub write {
-    my ( $self, $record ) = @_;
+    my ($self, $record) = @_;
 
-    $self->SUPER::write();
+    $self->count( $self->count + 1 );
 
     my $fh  = $self->fh;
     my $xml = ref($record) eq 'MARC::Record'
@@ -71,7 +72,7 @@ Koha::Contrib::Tamil::RecordWriter::File::Marcxml - XML MARC record reader
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 AUTHOR
 
